==> purchase-assist-domain-0.0.7-sources.jar: com/xforceplus/purchaserassist/entity/InvoiceVehicle.java <==
package com.xforceplus.purchaserassist.entity;

import java.math.BigDecimal;
import com.baomidou.mybatisplus.annotation.TableName;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-03-17
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("invoiceVehicle")
public class InvoiceVehicle implements Serializable {

  private static final long serialVersionUID=1L;

  private String vehicleType;

  private String vehicleBrand;

  private String origin;

  private String qualifiedNumber;

  private String bookNo;

  private String checkNo;

  private String engineNumber;

  private String identificationNumber;

  private String tonnage;

  private Integer maxCapacity;

  private String invoiceCode;

  private String invoiceNo;

  private String invoiceType;

  private BigDecimal totalAmountTaxNum;

  private BigDecimal totalAmount;

  private BigDecimal totalTax;

  private BigDecimal taxRate;

  private String paperDrewDate;

  private String sellerTaxNo;

  private String drawer;

  private String sellerName;

  private String sellerAddr;

  private String sellerTel;

  private String sellerBank;

  private String sellerBankNo;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserIdCode;

  private String codeOfTheCompetentTaxAuthority;

  private String nameOfTheCompetentTaxAuthority;

  private String taxPaidProof;

  private String qrcode;

  private String vehiclesType;

  private String machineCode;

  private String checkCode;

  private String sku;

  private String cipherList;

  private LocalDateTime invoiceTime;

  private Long userId;

  private Long collectionId;

  private Integer status;

  private String imgUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private String createUser;

  private String updateUser;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;




        }

==> purchase-assist-domain-0.0.14-sources.jar: com/xforceplus/purchaserassist/entity/InvoiceVehicle.java <==
package com.xforceplus.purchaserassist.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-04-02
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class InvoiceVehicle implements Serializable {

  private static final long serialVersionUID=1L;

  private String vehicleType;

  private String vehicleBrand;

  private String origin;

  private String qualifiedNumber;

  private String bookNo;

  private String checkNo;

  private String engineNumber;

  private String identificationNumber;

  private String tonnage;

  private Integer maxCapacity;

  private String invoiceCode;

  private String invoiceNo;

  private String invoiceType;

  private BigDecimal totalAmountTaxNum;

  private BigDecimal totalAmount;

  private BigDecimal totalTax;

  private BigDecimal taxRate;

  private String paperDrewDate;

  private String sellerTaxNo;

  private String drawer;

  private String sellerName;

  private String sellerAddr;

  private String sellerTel;

  private String sellerBank;

  private String sellerBankNo;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserIdCode;

  private String codeOfTheCompetentTaxAuthority;

  private String nameOfTheCompetentTaxAuthority;

  private String taxPaidProof;

  private String qrcode;

  private String vehiclesType;

  private String machineCode;

  private String checkCode;

  private String sku;

  private String cipherList;

  private LocalDateTime invoiceTime;

  private Long userId;

  private Long collectionId;

  private Integer status;

  private String imgUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;




        }
